'use strict';

var rollupPluginutils = require('rollup-pluginutils');
var ts = require('typescript');
var assign = require('object-assign');
assign = 'default' in assign ? assign['default'] : assign;

function typescript(options) {
    options = assign({}, options || {});
    var filter = rollupPluginutils.createFilter(options.include, options.exclude);
    delete options.include;
    delete options.exclude;
    return {
        transform: function (code, id) {
            if (!filter(id))
                return null;
            var transformed = ts.transpileModule(code, {
                compilerOptions: assign({
                    target: ts.ScriptTarget.ES5,
                    module: ts.ModuleKind.ES6,
                    sourceMap: true
                }, options)
            });
            if (transformed.diagnostics) {
                transformed.diagnostics.forEach(function (diagnostic) {
                    var _a = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start), line = _a.line, character = _a.character;
                    var message = ts.flattenDiagnosticMessageText(diagnostic.messageText, '\n');
                    console.log(diagnostic.file.fileName + " (" + (line + 1) + "," + (character + 1) + "): " + message);
                });
            }
            return {
                code: transformed.outputText,
                map: JSON.parse(transformed.sourceMapText)
            };
        }
    };
}

module.exports = typescript;
//# sourceMappingURL=index.js.map